==> eossdk-1.17.1.3.0-sources.jar: host/anzo/eossdk/eos/sdk/anticheat/client/options/EOS_AntiCheatClient_ReceiveMessageFromServerOptions.java <==
package host.anzo.eossdk.eos.sdk.anticheat.client.options;

import com.sun.jna.Memory;
import com.sun.jna.Pointer;
import com.sun.jna.Structure;
import org.jetbrains.annotations.NotNull;

import static com.sun.jna.Structure.FieldOrder;

/**
 * @author Anton Lasevich
 * @since 8/15/2023
 */
@FieldOrder({"ApiVersion", "DataLengthBytes", "Data"})
public class EOS_AntiCheatClient_ReceiveMessageFromServerOptions extends Structure {
	public static final int EOS_ANTICHEATCLIENT_RECEIVEMESSAGEFROMSERVER_API_LATEST = 1;

	/** API Version: Set this to {@link #EOS_ANTICHEATCLIENT_RECEIVEMESSAGEFROMSERVER_API_LATEST}. */
	public int ApiVersion;
	/** The size of the data received */
	public int DataLengthBytes;
	/** The data received */
	public Pointer Data;

	public EOS_AntiCheatClient_ReceiveMessageFromServerOptions() {
		super();
		ApiVersion = EOS_ANTICHEATCLIENT_RECEIVEMESSAGEFROMSERVER_API_LATEST;
	}

	/**
	 * @param data The data received
	 */
	public EOS_AntiCheatClient_ReceiveMessageFromServerOptions(byte @NotNull [] data) {
		this();
		Data = new Memory(data.length);
		Data.write(0, data, 0, data.length);
		DataLengthBytes = data.length;
	}

	public EOS_AntiCheatClient_ReceiveMessageFromServerOptions(Pointer peer) {
		super(peer);
	}

	public static class ByReference extends EOS_AntiCheatClient_ReceiveMessageFromServerOptions implements Structure.ByReference {
	}

	public static class ByValue extends EOS_AntiCheatClient_ReceiveMessageFromServerOptions implements Structure.ByValue {
	}
}

==> eossdk-1.18.0.4.0-sources.jar: host/anzo/eossdk/eos/sdk/anticheat/client/options/EOS_AntiCheatClient_ReceiveMessageFromServerOptions.java <==
package host.anzo.eossdk.eos.sdk.anticheat.client.options;

import com.sun.jna.Memory;
import com.sun.jna.Pointer;
import com.sun.jna.Structure;
import host.anzo.eossdk.eos.sdk.EOSLibrary;
import org.jetbrains.annotations.NotNull;

import static com.sun.jna.Structure.FieldOrder;

/**
 * Input parameters for the {@link EOSLibrary#EOS_AntiCheatClient_ReceiveMessageFromServer} function.
 * @author Anton Lasevich
 * @since 8/15/2023
 */
@FieldOrder({"ApiVersion", "DataLengthBytes", "Data"})
public class EOS_AntiCheatClient_ReceiveMessageFromServerOptions extends Structure {
	/** The most recent version of the EOS_AntiCheatClient_ReceiveMessageFromServer API. */
	public static final int EOS_ANTICHEATCLIENT_RECEIVEMESSAGEFROMSERVER_API_LATEST = 1;

	/** API Version: Set this to {@link #EOS_ANTICHEATCLIENT_RECEIVEMESSAGEFROMSERVER_API_LATEST}. */
	public int ApiVersion;
	/** The size of the data received */
	public int DataLengthBytes;
	/** The data received */
	public Pointer Data;

	public EOS_AntiCheatClient_ReceiveMessageFromServerOptions() {
		super();
		ApiVersion = EOS_ANTICHEATCLIENT_RECEIVEMESSAGEFROMSERVER_API_LATEST;
	}

	/**
	 * @param data The data received
	 */
	public EOS_AntiCheatClient_ReceiveMessageFromServerOptions(byte @NotNull [] data) {
		this();
		Data = new Memory(data.length);
		Data.write(0, data, 0, data.length);
		DataLengthBytes = data.length;
	}

	public EOS_AntiCheatClient_ReceiveMessageFromServerOptions(Pointer peer) {
		super(peer);
	}

	public static class ByReference extends EOS_AntiCheatClient_ReceiveMessageFromServerOptions implements Structure.ByReference {
	}

	public static class ByValue extends EOS_AntiCheatClient_ReceiveMessageFromServerOptions implements Structure.ByValue {
	}
}
